@@ -1,6 +1,8 @@
 /*-Matrice de poids W pour un processus Ornstein-Uhlenbeck multivarie-----------------*/
 /*-mvMORPH 1.0.2 - 2014 - Julien Clavel - julien.clavel@hotmail.fr--------------------*/
-#include "ouch.h"
+/*-Modified with permission from A. King OUCH ----------------------------------------*/
+
+#include "mvmorph.h"
 
 static void simmap_weight_matrix (int *nchar, int *neps, double *epochs, double *lambda, double *S, double *y) {
   double *elt;
